Welcome to ClientVPS Mirrors

Help for package doSNOW
Type: Package
Title: Foreach Parallel Adaptor for the 'snow' Package
Version: 1.0.20
Description: Provides a parallel backend for the %dopar% function using the snow package of Tierney, Rossini, Li, and Sevcikova.
Depends: R (≥ 2.5.0), foreach(≥ 1.2.0), iterators(≥ 1.0.0), snow(≥ 0.3.0), utils
Suggests: compiler, RUnit, caret, mlbench, rpart, parallel
License: GPL-2
NeedsCompilation: no
Packaged: 2022-01-16 18:34:00 UTC; folashade
Author: Folashade Daniel [cre], Microsoft Corporation [aut, cph], Stephen Weston [aut]
Maintainer: Folashade Daniel <fdaniel@microsoft.com>
Repository: CRAN
Date/Publication: 2022-02-04 16:20:06 UTC

registerDoSNOW

Description

The registerDoSNOW function is used to register the SNOW parallel backend with the foreach package.

Usage

registerDoSNOW(cl)

Arguments

cl

The cluster object to use for parallel execution.

See Also

makeCluster

Examples


cl <- makeCluster(2, type="SOCK")
registerDoSNOW(cl)
m <- matrix(rnorm(9), 3, 3)
foreach(i=1:nrow(m), .combine=rbind) %dopar%  (m[i,] / mean(m[i,]))
stopCluster(cl)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.